@@ -97,6 +97,20 @@ public:
         return NoRestriction;
     }
 
+    /** Classify the files and return the most appropiate commands.
+     *
+     * @param files: A list of files.
+     *
+     * @returns null QString on success. Error message otherwise.
+     */
+    static QVector<Command *>commandsForFiles(const QStringList &files);
+
+    /** Get a command for a query.
+     *
+     * @param query: A keyid / fingerprint or any string to use in the search.
+     */
+    static Command *commandForQuery(const QString &query);
+
     void setParentWidget(QWidget *widget);
     void setParentWId(WId wid);
     void setView(QAbstractItemView *view);
