@@ -37,7 +37,7 @@
 #include "signencryptfilestask.h"
 #include "certificateresolver.h"
 
-#include <crypto/gui/newsignencryptfileswizard.h>
+#include <crypto/gui/signencryptfileswizard.h>
 #include <crypto/taskcollection.h>
 
 #include <utils/input.h>
@@ -115,7 +115,7 @@ private:
 private:
     std::vector< shared_ptr<SignEncryptFilesTask> > runnable, completed;
     shared_ptr<SignEncryptFilesTask> cms, openpgp;
-    QPointer<NewSignEncryptFilesWizard> wizard;
+    QPointer<SignEncryptFilesWizard> wizard;
     QStringList files;
     unsigned int operation;
     Protocol protocol;
@@ -143,12 +143,12 @@ QString SignEncryptFilesController::Private::titleForOperation(unsigned int op)
 {
     const bool signDisallowed = (op & SignMask) == SignDisallowed;
     const bool encryptDisallowed = (op & EncryptMask) == EncryptDisallowed;
-    const bool archiveForced = (op & ArchiveMask) == ArchiveForced;
+    const bool archiveSelected = (op & ArchiveMask) == ArchiveForced;
 
     kleo_assert(!signDisallowed || !encryptDisallowed);
 
     if (!signDisallowed && encryptDisallowed) {
-        if (archiveForced) {
+        if (archiveSelected) {
             return i18n("Archive and Sign Files");
         } else {
             return i18n("Sign Files");
@@ -156,14 +156,14 @@ QString SignEncryptFilesController::Private::titleForOperation(unsigned int op)
     }
 
     if (signDisallowed && !encryptDisallowed) {
-        if (archiveForced) {
+        if (archiveSelected) {
             return i18n("Archive and Encrypt Files");
         } else {
             return i18n("Encrypt Files");
         }
     }
 
-    if (archiveForced) {
+    if (archiveSelected) {
         return i18n("Archive and Sign/Encrypt Files");
     } else {
         return i18n("Sign/Encrypt Files");
@@ -210,10 +210,10 @@ void SignEncryptFilesController::Private::assertValidOperation(unsigned int op)
 {
     kleo_assert((op & SignMask)    == SignDisallowed    ||
                 (op & SignMask)    == SignAllowed       ||
-                (op & SignMask)    == SignForced);
+                (op & SignMask)    == SignSelected);
     kleo_assert((op & EncryptMask) == EncryptDisallowed ||
                 (op & EncryptMask) == EncryptAllowed    ||
-                (op & EncryptMask) == EncryptForced);
+                (op & EncryptMask) == EncryptSelected);
     kleo_assert((op & ArchiveMask) == ArchiveDisallowed ||
                 (op & ArchiveMask) == ArchiveAllowed    ||
                 (op & ArchiveMask) == ArchiveForced);
@@ -239,45 +239,41 @@ void SignEncryptFilesController::Private::updateWizardMode()
     const unsigned int signOp = (operation & SignMask);
     const unsigned int encrOp = (operation & EncryptMask);
     const unsigned int archOp = (operation & ArchiveMask);
-    switch (signOp) {
-    case SignForced:
-    case SignDisallowed:
-        wizard->setSigningPreset(signOp == SignForced);
+
+    if (signOp == SignDisallowed) {
         wizard->setSigningUserMutable(false);
-        break;
-    default:
-        assert(!"Should not happen");
-    case SignAllowed:
-        wizard->setSigningPreset(encrOp == EncryptDisallowed);
+        wizard->setSigningPreset(false);
+    } else {
         wizard->setSigningUserMutable(true);
-        break;
+        wizard->setSigningPreset(false);
+
+        if (signOp == SignSelected) {
+            wizard->setSigningPreset(true);
+        }
     }
-    switch (encrOp) {
-    case EncryptForced:
-    case EncryptDisallowed:
-        wizard->setEncryptionPreset(encrOp == EncryptForced);
+
+    if (encrOp == EncryptDisallowed) {
+        wizard->setEncryptionPreset(false);
         wizard->setEncryptionUserMutable(false);
-        break;
-    default:
-        assert(!"Should not happen");
-    case EncryptAllowed:
-        wizard->setEncryptionPreset(true);
+    } else {
         wizard->setEncryptionUserMutable(true);
-        break;
+        wizard->setEncryptionPreset(false);
+
+        if (encrOp == EncryptSelected) {
+            wizard->setEncryptionPreset(true);
+        }
     }
-    switch (archOp) {
-    case ArchiveForced:
-    case ArchiveDisallowed:
-        wizard->setCreateArchivePreset(archOp == ArchiveForced);
-        wizard->setCreateArchiveUserMutable(false);
-        break;
-    default:
-        assert(!"Shouldn't happen");
-    case ArchiveAllowed:
+
+    if (archOp == ArchiveDisallowed) {
         wizard->setCreateArchivePreset(false);
-        wizard->setEncryptionUserMutable(true);
-        break;
-    };
+        wizard->setCreateArchiveUserMutable(false);
+    } else if (archOp == ArchiveForced) {
+        wizard->setCreateArchiveUserMutable(false);
+        wizard->setCreateArchivePreset(true);
+    } else {
+        wizard->setCreateArchiveUserMutable(true);
+        wizard->setCreateArchivePreset(false);
+    }
 }
 
 unsigned int SignEncryptFilesController::operationMode() const
@@ -324,13 +320,12 @@ static const char *extension(bool pgp, bool sign, bool encrypt, bool ascii, bool
 }
 
 static shared_ptr<SignEncryptFilesTask>
-createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool pgp, bool sign, bool encrypt, bool ascii, bool removeUnencrypted, const std::vector<Key> &recipients, const std::vector<Key> &signers)
+createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool pgp, bool sign, bool encrypt, bool ascii, const std::vector<Key> &recipients, const std::vector<Key> &signers)
 {
     const shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
     task->setSign(sign);
     task->setEncrypt(encrypt);
     task->setAsciiArmor(ascii);
-    task->setRemoveInputFileOnSuccess(removeUnencrypted);
     if (sign) {
         task->setSigners(signers);
         task->setDetachedSignature(true);
@@ -353,13 +348,12 @@ createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool pgp, bool sign, bool
 }
 
 static shared_ptr<SignEncryptFilesTask>
-createArchiveSignEncryptTaskForFiles(const QStringList &files, const QString &outputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool pgp, bool sign, bool encrypt, bool ascii, bool removeUnencrypted, const std::vector<Key> &recipients, const std::vector<Key> &signers)
+createArchiveSignEncryptTaskForFiles(const QStringList &files, const QString &outputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool pgp, bool sign, bool encrypt, bool ascii, const std::vector<Key> &recipients, const std::vector<Key> &signers)
 {
     const shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
     task->setSign(sign);
     task->setEncrypt(encrypt);
     task->setAsciiArmor(ascii);
-    task->setRemoveInputFileOnSuccess(removeUnencrypted);
     if (sign) {
         task->setSigners(signers);
         task->setDetachedSignature(false);
@@ -385,7 +379,7 @@ createArchiveSignEncryptTaskForFiles(const QStringList &files, const QString &ou
 }
 
 static std::vector< shared_ptr<SignEncryptFilesTask> >
-createSignEncryptTasksForFileInfo(const QFileInfo &fi, bool sign, bool encrypt, bool ascii, bool removeUnencrypted, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
+createSignEncryptTasksForFileInfo(const QFileInfo &fi, bool sign, bool encrypt, bool ascii, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
 {
     std::vector< shared_ptr<SignEncryptFilesTask> > result;
 
@@ -400,17 +394,17 @@ createSignEncryptTasksForFileInfo(const QFileInfo &fi, bool sign, bool encrypt,
     result.reserve(pgp + cms);
 
     if (pgp) {
-        result.push_back(createSignEncryptTaskForFileInfo(fi, true, sign, encrypt, ascii, removeUnencrypted, pgpRecipients, pgpSigners));
+        result.push_back(createSignEncryptTaskForFileInfo(fi, true, sign, encrypt, ascii, pgpRecipients, pgpSigners));
     }
     if (cms) {
-        result.push_back(createSignEncryptTaskForFileInfo(fi, false, sign, encrypt, ascii, removeUnencrypted, cmsRecipients, cmsSigners));
+        result.push_back(createSignEncryptTaskForFileInfo(fi, false, sign, encrypt, ascii, cmsRecipients, cmsSigners));
     }
 
     return result;
 }
 
 static std::vector< shared_ptr<SignEncryptFilesTask> >
-createArchiveSignEncryptTasksForFiles(const QStringList &files, const QString &pgpOutputFileBaseName, const QString &cmsOutputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool sign, bool encrypt, bool ascii, bool removeUnencrypted, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
+createArchiveSignEncryptTasksForFiles(const QStringList &files, const QString &pgpOutputFileBaseName, const QString &cmsOutputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool sign, bool encrypt, bool ascii, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
 {
     std::vector< shared_ptr<SignEncryptFilesTask> > result;
 
@@ -425,10 +419,10 @@ createArchiveSignEncryptTasksForFiles(const QStringList &files, const QString &p
     result.reserve(pgp + cms);
 
     if (pgp) {
-        result.push_back(createArchiveSignEncryptTaskForFiles(files, pgpOutputFileBaseName, ad, true,  sign, encrypt, ascii, removeUnencrypted, pgpRecipients, pgpSigners));
+        result.push_back(createArchiveSignEncryptTaskForFiles(files, pgpOutputFileBaseName, ad, true,  sign, encrypt, ascii, pgpRecipients, pgpSigners));
     }
     if (cms) {
-        result.push_back(createArchiveSignEncryptTaskForFiles(files, cmsOutputFileBaseName, ad, false, sign, encrypt, ascii, removeUnencrypted, cmsRecipients, cmsSigners));
+        result.push_back(createArchiveSignEncryptTaskForFiles(files, cmsOutputFileBaseName, ad, false, sign, encrypt, ascii, cmsRecipients, cmsSigners));
     }
 
     return result;
@@ -448,7 +442,6 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
         const bool encrypt = wizard->isEncryptionSelected();
 
         const bool ascii = wizard->isAsciiArmorEnabled();
-        const bool removeUnencrypted = wizard->isRemoveUnencryptedFilesEnabled();
 
         std::vector<Key> pgpRecipients, cmsRecipients, pgpSigners, cmsSigners;
         if (encrypt) {
@@ -482,12 +475,12 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
                     wizard->archiveFileName(OpenPGP),
                     wizard->archiveFileName(CMS),
                     wizard->selectedArchiveDefinition(),
-                    sign, encrypt, ascii, removeUnencrypted,
+                    sign, encrypt, ascii,
                     pgpRecipients, pgpSigners, cmsRecipients, cmsSigners);
         else
             Q_FOREACH (const QString &file, files) {
                 const std::vector< shared_ptr<SignEncryptFilesTask> > created =
-                    createSignEncryptTasksForFileInfo(QFileInfo(file), sign, encrypt, ascii, removeUnencrypted, pgpRecipients, pgpSigners, cmsRecipients, cmsSigners);
+                    createSignEncryptTasksForFileInfo(QFileInfo(file), sign, encrypt, ascii, pgpRecipients, pgpSigners, cmsRecipients, cmsSigners);
                 tasks.insert(tasks.end(), created.begin(), created.end());
             }
 
@@ -615,7 +608,7 @@ void SignEncryptFilesController::Private::ensureWizardCreated()
         return;
     }
 
-    std::unique_ptr<NewSignEncryptFilesWizard> w(new NewSignEncryptFilesWizard);
+    std::unique_ptr<SignEncryptFilesWizard> w(new SignEncryptFilesWizard);
     w->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(w.get(), SIGNAL(operationPrepared()), q, SLOT(slotWizardOperationPrepared()), Qt::QueuedConnection);
