@@ -45,6 +45,7 @@
 #include <utils/kdpipeiodevice.h>
 #include <utils/log.h>
 #include <utils/getpid.h>
+#include "utils/classify.h"
 
 #include <gpgme++/key.h>
 #include <models/keycache.h>
@@ -53,10 +54,12 @@
 # include <uiserver/uiserver.h>
 #endif
 
-#include <commands/signencryptfilescommand.h>
-#include <commands/decryptverifyfilescommand.h>
-#include <commands/lookupcertificatescommand.h>
-#include <commands/detailscommand.h>
+#include "commands/signencryptfilescommand.h"
+#include "commands/decryptverifyfilescommand.h"
+#include "commands/lookupcertificatescommand.h"
+#include "commands/checksumcreatefilescommand.h"
+#include "commands/checksumverifyfilescommand.h"
+#include "commands/detailscommand.h"
 
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -236,7 +239,9 @@ void KleopatraApplication::slotActivateRequested(const QStringList &arguments,
     if (!err.isEmpty()) {
         KMessageBox::sorry(NULL, err.toHtmlEscaped(), i18n("Failed to execute command"));
         Q_EMIT setExitValue(1);
+        return;
     }
+    Q_EMIT setExitValue(0);
 }
 
 QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
@@ -305,24 +310,13 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
 
     // Check for --query command
     if (parser.isSet(QStringLiteral("query"))) {
-        const QString fingerPrint = parser.value(QStringLiteral("query"));
-        if (fingerPrint.isEmpty()) {
+        const QString query = parser.value(QStringLiteral("query"));
+        if (query.isEmpty()) {
             return i18n("No fingerprint argument specified for --query");
         }
-
-        // Search for local keys
-        const GpgME::Key &key = Kleo::KeyCache::instance()->findByKeyIDOrFingerprint(fingerPrint.toLocal8Bit().data());
-        if (key.isNull()) {
-            // Show external search dialog
-            LookupCertificatesCommand *const cmd = new LookupCertificatesCommand(fingerPrint, 0);
-            cmd->setParentWId(parentId);
-            cmd->start();
-        } else {
-            // show local detail
-            DetailsCommand *const cmd = new DetailsCommand(key, 0);
-            cmd->setParentWId(parentId);
-            cmd->start();
-        }
+        auto cmd = Command::commandForQuery(query);
+        cmd->setParentWId(parentId);
+        cmd->start();
         return QString();
     }
 
@@ -334,7 +328,8 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
         { QStringLiteral("sign-encrypt"), &KleopatraApplication::signEncryptFiles },
         { QStringLiteral("decrypt"), &KleopatraApplication::decryptFiles },
         { QStringLiteral("verify"), &KleopatraApplication::verifyFiles },
-        { QStringLiteral("decrypt-verify"), &KleopatraApplication::decryptVerifyFiles }
+        { QStringLiteral("decrypt-verify"), &KleopatraApplication::decryptVerifyFiles },
+        { QStringLiteral("checksum"), &KleopatraApplication::checksumFiles },
     };
 
     QString found;
@@ -359,7 +354,18 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
                 openOrRaiseMainWindow();
             }
         } else {
-            return i18n("No command provided but arguments present");
+            QStringList errors;
+            Q_FOREACH (const QString& fileName, files) {
+                QFileInfo fi(fileName);
+                if (!fi.isReadable()) {
+                    errors << i18n("Cannot read \"%1\"", fileName);
+                }
+            }
+            Q_FOREACH (Command *cmd, Command::commandsForFiles(files)) {
+                cmd->setParentWId(parentId);
+                cmd->start();
+            }
+            return errors.join("\n");
         }
     }
 
@@ -541,6 +547,28 @@ void KleopatraApplication::decryptVerifyFiles(const QStringList &files, GpgME::P
     cmd->start();
 }
 
+void KleopatraApplication::checksumFiles(const QStringList &files, GpgME::Protocol /*proto*/)
+{
+    QStringList verifyFiles, createFiles;
+
+    Q_FOREACH (const QString &file, files) {
+        if (isChecksumFile(file)) {
+            verifyFiles << file;
+        } else {
+            createFiles << file;
+        }
+    }
+
+    if (!verifyFiles.isEmpty()) {
+        auto *const cmd = new ChecksumVerifyFilesCommand(verifyFiles, 0);
+        cmd->start();
+    }
+    if (!createFiles.isEmpty()) {
+        auto *const cmd = new ChecksumCreateFilesCommand(createFiles, 0);
+        cmd->start();
+    }
+}
+
 void KleopatraApplication::setIgnoreNewInstance(bool ignore)
 {
     d->ignoreNewInstance = ignore;
@@ -550,4 +578,3 @@ bool KleopatraApplication::ignoreNewInstance() const
 {
     return d->ignoreNewInstance;
 }
-
